@@ -2,11 +2,10 @@
 //! and functions that generate closures.
 pub mod convenience;
 pub mod parse;
-#[cfg(feature = "status-report")]
-pub mod status_report;
 
-#[cfg(feature = "status-report")]
-pub use status_report::statusReport;
+cfg_status_report!(
+    pub mod status_report;
+);
 
 pub use convenience::functions;
 pub use parse::shell_command::parse_and_run;
